@@ -1,6 +1,7 @@
 # The contents of this file is free and unencumbered software released into the
 # public domain. For more information, please refer to <http://unlicense.org/>
-
+from anilistWrapPY.errors.types import AniListError
+from anilistWrapPY.errors.ex_class import AniListException
 from anilistWrapPY.Character.types import AniListCharacter
 from anilistWrapPY.Character.graphql import character_query
 import httpx
@@ -9,4 +10,7 @@ import httpx
 def GetCharacter(search: str, baseUrl: str) -> AniListCharacter:
     variables = {"search": search}
     r = (httpx.post(baseUrl, json={"query": character_query, "variables": variables})).json()
-    return AniListCharacter(**r)
\ No newline at end of file
+    try:
+        return AniListCharacter(**r)
+    except AniListException:
+        return AniListError(**r)
\ No newline at end of file
